PCB Environment: dsn::Connection Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Data Fields
dsn::Connection Struct Reference

## Data Fields
std::string | src_pin
std::string | dst_pin
bool | has_src_pin {false}
bool | has_dst_pin {false}
bool | has_src {false}
bool | has_dst {false}
double | x0
double | y0
double | x1
double | y1
int | z0
int | z1
double | clearance
double | ref_len {0.0}
std::vector< Track > | tracks

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp